@@ -1,5 +1,5 @@
 
-from macman import cocoadialog
+from macman import dialog
 from macman import files
 from macman import logs
 from macman import misc
@@ -8,10 +8,11 @@ from macman import plists
 from macman import remoteaccess
 from macman import systime
 from macman import users
+from macman import network
 
-__version__ = 1.76
+__version__ = 4.1
 
 # if no log file specified, don't use log
 if '__builtin__log' not in locals():
     import __builtin__
-    __builtin__.log = None
\ No newline at end of file
+    __builtin__.log = None
